Welcome to Stem!
================

Stem is a Python controller library for `Tor <https://www.torproject.org/>`_. With it you can use Tor's `control protocol <https://gitweb.torproject.org/torspec.git/tree/control-spec.txt>`_ to script against the Tor process, or build things such as `Nyx <https://nyx.torproject.org/>`_. Stem's latest version is **1.8** (released December 29th, 2019).

.. Main Stem Logo
   Source: http://www.wpclipart.com/plants/assorted/P/plant_stem.png.html
   Author: Jakub Jankiewicz
   License: Public Domain (http://www.wpclipart.com/legal.html#terms)
   
   Alternate:
   Source: http://andreajoseph24.blogspot.com/search/label/onions
   Author: Andrea Joseph
   License: CCv3 (NC, ND) - http://creativecommons.org/licenses/by-nc-nd/3.0/

.. Source: NuoveXT 2 (http://nuovext.pwsp.net/)
   Author: Alexandre Moore (http://sa-ki.deviantart.com/)
   License: LGPL v3
   File: NuoveXT 2.2/128x128/categories/applications-development.png

.. image:: /_static/buttons/tutorials.png
   :target: tutorials.html

.. Source: http://www.cipherdyne.com/images/anvil.png
   Author and license are unknown

.. image:: /_static/buttons/api.png
   :target: api.html

.. Source: https://openclipart.org/detail/171951/help-by-diamonjohn-171951
   Author: John Diamond (https://openclipart.org/user-detail/diamonjohn)
   License: Public Domain
   
   Alternate:
   Source: Oxygen (http://www.oxygen-icons.org/)
   Author: Andrea Joseph
   License: CCv3 (A, SA) - http://creativecommons.org/licenses/by-sa/3.0/
   File: Oxygen/128x128/categories/system-help.png

.. image:: /_static/buttons/faq.png
   :target: faq.html

.. Source: Nuovo (http://www.silvestre.com.ar/?p=5)
   Author: Silvestre Herrera (http://www.silvestre.com.ar/)
   License: GPL v2
   File: Nuovo/128x128/mimetypes/gnome-mime-text-log.png

.. image:: /_static/buttons/change_log.png
   :target: change_log.html

.. Source: Crystal (http://www.everaldo.com/crystal/)
   Author: Everaldo Coelho (http://www.everaldo.com/)
   License: LGPL v2
   File: Crystal/64x64/apps/bug.png

.. image:: /_static/buttons/bug_tracker.png
   :target: https://github.com/torproject/stem/issues/

.. Source: ColorCons (http://mouserunner.com/Spheres_ColoCons1_Free_Icons.html)
   Author: Ken Saunders (http://mouserunner.com/MRDS_Cell.html)
   License: CC v2.5 (A, SA)
   File: ColorCons/Blue/Download.png

.. image:: /_static/buttons/download.png
   :target: download.html

.. toctree::
   :maxdepth: 1

